<template>
  <a-card :bordered="false">
    <div class="table-page-search-wrapper" @keyup.enter="handleEnter">
      <a-form layout="inline">
        <a-row :gutter="48">
          <a-col :md="8" :sm="24">
            <a-form-item label="关键字">
              <a-input v-model="queryParam.keyword" placeholder="请输入备件名称/备件编码"/>
            </a-form-item>
          </a-col>
          <a-col :md="8 || 24" :sm="24">
            <span class="table-page-search-submitButtons">
              <a-button type="primary" @click="$refs.table.refresh(true)">查询</a-button>
              <a-button style="margin-left: 8px" @click="resetSearchForm">重置</a-button>
            </span>
          </a-col>
        </a-row>
      </a-form>
    </div>

    <div class="table-operator">
      <!--<a-button v-if="$auth('store-spare-stores-add')" type="primary" icon="plus" @click="$refs.baseModal.base()">新增</a-button>-->
      <a-button style="margin-left: 8px" v-if="$auth('store-spare-stores-export')" type="primary" icon="download" @click="doExport">导出</a-button>
    </div>

    <s-table
      ref="table"
      size="default"
      rowKey="id"
      :columns="columns"
      :data="loadData"
      :alert="options.alert"
      :rowSelection="options.rowSelection"
      showPagination="auto"
    >
      <span slot="action" slot-scope="record">
        <template>
          <a @click="handleSparePartUsed(record)">使用记录</a>
          <a-divider type="vertical" />
          <a @click="handleSpareRestoreDetail(record)">退库记录</a>
        </template>
      </span>
      <span slot="delFlag" slot-scope="text">
        <badge
          :status="DictCache.COLOR.DELFLAG[text]"
          :text="delFlagMap[text]" />
      </span>
    </s-table>
    <base-form ref="baseModal" @ok="handleOk"/>
    <detail ref="detailModal"/>
    <spare-part-used-select-modal ref="sparePartUsedSelectModal"/>
    <spare-restore-detail-select-modal ref="spareRestoreDetailSelectModal"/>
  </a-card>
</template>

<script>
import { STable, Ellipsis } from '@/components'
import BaseForm from './modules/BaseForm'
import Detail from './modules/Detail'
import { getSpareStorePage, deleteSpareStores, fetchSpareStore, exportSpareStore,fetchSparePartUsedList,fetchSpareReStoreDetailList } from '@/api/store/sparestoresecond'
import SparePartUsedSelectModal from '@/views/sqarepartmanage/sparepartused/modules/SparePartUsedSelectModal'
import SpareRestoreDetailSelectModal from '@/views/store/sparerestoredetail/modules/SpareRestoreDetailSelectModal'

export default {
  name: 'SpareStoreSecondList',
  components: {
    STable,
    Ellipsis,
    BaseForm,
    Detail,
    SparePartUsedSelectModal,
    SpareRestoreDetailSelectModal
  },
  data () {
    return {
      // 查询参数
      queryParam: {
      },
      // 表头
      columns: [
        {
          title: '序号',
          dataIndex: 'index',
          customRender: (text, record, index) => {
            return `${(this.$refs.table.localPagination.current - 1) * this.$refs.table.localPagination.pageSize + index + 1}`
          }
        },
        {
          title: '备件名称',
          dataIndex: 'spareName'
        },
        {
          title: '归属人',
          dataIndex: 'belongUserId'
        },
        {
          title: '归属人名称',
          dataIndex: 'belongUserName'
        },
        {
          title: '已使用数量',
          dataIndex: 'usedNum'
        },
        {
          title: '总数量',
          dataIndex: 'totalNum'
        },
        {
          title: '备注',
          dataIndex: 'remark'
        },
        {
          title: '是否删除',
          dataIndex: 'delFlag',
          scopedSlots: { customRender: 'delFlag' }
        },
        {
          title: '创建日期',
          dataIndex: 'createdTime'
        },
        {
          title: '操作',
          key: 'action',
          width: '200px',
          align: 'center',
          scopedSlots: { customRender: 'action' }
        }
      ],
      // 下拉框map
      delFlagMap: {},
      // 加载数据方法 必须为 Promise 对象
      loadData: parameter => {
        parameter = {
          ...parameter,
          ...this.queryParam,
          dataScope: {
          }
        }
        return getSpareStorePage(Object.assign(parameter, this.queryParam))
          .then(res => {
            return res.data
          })
      },
      selectedRowKeys: [],
      selectedRows: [],

      options: {
        alert: { show: true, clear: () => { this.selectedRowKeys = [] } },
        rowSelection: {
          selectedRowKeys: this.selectedRowKeys,
          onChange: this.onSelectChange
        }
      },
      optionAlertShow: false
    }
  },
  created () {
    // 下拉框map
    this.delFlagMap = this.DictCache.getLabelByValueMapByType(this.DictCache.TYPE.DELFLAG)
    this.tableOption()
  },
  methods: {
    tableOption () {
      if (!this.optionAlertShow) {
        this.options = {
          alert: { show: true, clear: () => { this.selectedRowKeys = [] } },
          rowSelection: {
            selectedRowKeys: this.selectedRowKeys,
            onChange: this.onSelectChange,
            getCheckboxProps: record => ({
              props: {
                disabled: false,
                name: record.id
              }
            })
          }
        }
        this.optionAlertShow = true
      } else {
        this.options = {
          alert: false,
          rowSelection: null
        }
        this.optionAlertShow = false
      }
    },
    batchDelete (id) {
      let ids = []
      if (this.BaseTool.String.isBlank(id)) {
        const length = this.selectedRows.length
        if (length === 0) {
          this.$message.info('请选择要删除的记录')
          return
        }
        ids = this.selectedRows.map(item => item.id)
      } else {
        ids = [id]
      }
      deleteSpareStores(ids).then(res => {
        this.$message.info('删除成功')
        this.handleOk()
        this.$refs.table.clearSelected()
      })
    },
    handleEdit (record) {
      fetchSpareStore({ id: record.id }).then(res => {
        const modal = this.$refs.baseModal
        modal.base(res.data)
      })
    },
    handleView (record) {
      fetchSpareStore({ id: record.id }).then(res => {
        const modal = this.$refs.detailModal
        modal.base(res.data)
      })
    },
    handleOk () {
      this.$refs.table.refresh()
    },
    handleSparePartUsed (record) {
      fetchSparePartUsedList({ id: record.id }).then(res => {
        const modal = this.$refs.sparePartUsedSelectModal
        modal.base(res.data)
      })
    },
    handleSpareRestoreDetail (record) {
      fetchSpareReStoreDetailList({ id: record.id }).then(res => {
        const modal = this.$refs.spareRestoreDetailSelectModal
        modal.base(res.data)
      })
    },
    onSelectChange (selectedRowKeys, selectedRows) {
      this.selectedRowKeys = selectedRowKeys
      this.selectedRows = selectedRows
    },
    resetSearchForm () {
      this.queryParam = {
      }
      this.$refs.table.refresh(true)
    },
    doExport () {
      const parameter = {
        ...this.queryParam
      }
      exportSpareStore(parameter).then(file => {
        this.BaseTool.UPLOAD.downLoadExportExcel(file)
      })
    },
    handleEnter () {
      this.$refs.table.refresh(true)
    }
  }
}
</script>
